( cd boot ; rm -rf System.map-versatile )
( cd boot ; ln -sf System.map-versatile-2.6.30.5 System.map-versatile )
( cd boot ; rm -rf zImage-versatile )
( cd boot ; ln -sf zImage-versatile-2.6.30.5 zImage-versatile )
( cd boot ; rm -rf initrd-versatile.gz )
( cd boot ; ln -sf initrd-versatile-2.6.30.5.gz initrd-versatile.gz )
